==> versus-tools-1.0.5.tgz: package/module.js <==
const codeGenerator = (length) => {
    var result           = '';
    var characters       = 'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789';
    for ( var i = 0; i < length; i++ ) {
       result += characters.charAt(Math.floor(Math.random() * characters.length));
    }
    return result;
};
const colors = {
    blue: 4214184,
    darkblue: 262374,
    cyan: 4249302,
    lightblue: 9943016,
    brown: 6167043,
    darkred: 8717059,
    red: 16711680,
    lightred: 12864593,
    orange: 14370048,
    darkorange: 10695680,
    darkyellow: 12229378,
    yellow: 16036864,
    lightyellow: 14805006,
    beige: 14913869,
    gold: 8540676,
    green: 1023320,
    darkgreen: 1930500,
    lightgreen: 9492092,
    yellowgreen: 12962816,
    lightpink: 14451962,
    darkpurple: 5046868,
    pink: 13894851,
    silver: 8026489,
    lightgrey: 11579568,
    grey: 3158064,
    black: 0,
    white: 16448250,
    purple: 7997644
};
const toLocaleDate = (date) => {
    if(typeof date !== "string") return false;
    
    var days = date.includes("d") ? date.split("d")[1] : "";
    var hours = date.includes("h") ? date.split("h")[1].slice(days ? days.length + 1 : 0) : "";
    var minutes = date.includes("m") ? date.split("m")[1].slice(days ? days.length + 1 : 0).slice(hours ? hours.length + 1 : 0) : "";
    var seconds = date.includes("s") ? date.split("s")[1].slice(days ? days.length + 1 : 0).slice(hours ? hours.length + 1 : 0).slice(minutes ? minutes.length + 1 : 0) : "";
    
    if(!days && !hours && !minutes && !seconds) return false;
    
    var time = [];
    if(days > 0) time.push(days <= 1 ? `${days} jour` : `${days} jours`);
    if(hours > 0) time.push(hours <= 1 ? `${hours} heure` : `${hours} heures`);
    if(minutes > 0) time.push(minutes <= 1 ? `${minutes} minute` : `${minutes} minutes`);
    if(seconds > 0) time.push(seconds <= 1 ? `${seconds} seconde` : `${seconds} secondes`);
    return time.join(", ");
};
const toRemaining = (date) => {
    if(typeof date !== "string") return false;
    
    var days = date.includes("d") ? date.split("d")[1] : "";
    var hours = date.includes("h") ? date.split("h")[1].slice(days ? days.length + 1 : 0) : "";
    var minutes = date.includes("m") ? date.split("m")[1].slice(days ? days.length + 1 : 0).slice(hours ? hours.length + 1 : 0) : "";
    var seconds = date.includes("s") ? date.split("s")[1].slice(days ? days.length + 1 : 0).slice(hours ? hours.length + 1 : 0).slice(minutes ? minutes.length + 1 : 0) : "";
    
    var duration = 0;
    if(days) duration += parseInt(days) * 86400000;
    if(hours) duration += parseInt(hours) * 3600000;
    if(minutes) duration += parseInt(minutes) * 60000;
    if(seconds) duration += parseInt(seconds) * 1000;

    return duration;
};
const toFormatDate = (date, format) => {
    if(typeof date !== "string" || typeof format !== "string") return false;
    
    var days = date.includes("d") ? date.split("d")[1] : "";
    var hours = date.includes("h") ? date.split("h")[1].slice(days ? days.length + 1 : 0) : "";
    var minutes = date.includes("m") ? date.split("m")[1].slice(days ? days.length + 1 : 0).slice(hours ? hours.length + 1 : 0) : "";
    var seconds = date.includes("s") ? date.split("s")[1].slice(days ? days.length + 1 : 0).slice(hours ? hours.length + 1 : 0).slice(minutes ? minutes.length + 1 : 0) : "";
    
    if(!days && !hours && !minutes && !seconds) return false;
    format.replace(/DD/g, days)
        .replace(/HH/g, hours < 10 ? `0${hours}` : hours)
        .replace(/mm/g, minutes < 10 ? `0${minutes}` : minutes)
        .replace(/ss/g, seconds < 10 ? `0${seconds}` : seconds)
    return {
        format: format,
        days: days,
        hours: hours,
        minutes: minutes,
        seconds: seconds
    };
};

module.exports = {
    codeGenerator, colors,
    toLocaleDate, toRemaining,
    toFormatDate
}

==> versus-tools-1.0.8.tgz: package/module.js <==
const codeGenerator = (length) => {
    var result           = '';
    var characters       = 'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789';
    for ( var i = 0; i < length; i++ ) {
       result += characters.charAt(Math.floor(Math.random() * characters.length));
    }
    return result;
};
const colors = {
    blue: 4214184,
    darkblue: 262374,
    cyan: 4249302,
    lightblue: 9943016,
    brown: 6167043,
    darkred: 8717059,
    red: 16711680,
    lightred: 12864593,
    orange: 14370048,
    darkorange: 10695680,
    darkyellow: 12229378,
    yellow: 16036864,
    lightyellow: 14805006,
    beige: 14913869,
    gold: 8540676,
    green: 1023320,
    darkgreen: 1930500,
    lightgreen: 9492092,
    yellowgreen: 12962816,
    lightpink: 14451962,
    darkpurple: 5046868,
    pink: 13894851,
    silver: 8026489,
    lightgrey: 11579568,
    grey: 3158064,
    black: 0,
    white: 16448250,
    purple: 7997644
};
const toLocaleDate = (date) => {
    if(typeof date !== "string") return false;
    
    var days = date.includes("d") ? date.split("d")[1] : "";
    var hours = date.includes("h") ? date.split("h")[1].slice(days ? days.length + 1 : 0) : "";
    var minutes = date.includes("m") ? date.split("m")[1].slice(days ? days.length + 1 : 0).slice(hours ? hours.length + 1 : 0) : "";
    var seconds = date.includes("s") ? date.split("s")[1].slice(days ? days.length + 1 : 0).slice(hours ? hours.length + 1 : 0).slice(minutes ? minutes.length + 1 : 0) : "";
    
    if(!days && !hours && !minutes && !seconds) return false;
    
    var time = [];
    if(days > 0) time.push(days <= 1 ? `${days} jour` : `${days} jours`);
    if(hours > 0) time.push(hours <= 1 ? `${hours} heure` : `${hours} heures`);
    if(minutes > 0) time.push(minutes <= 1 ? `${minutes} minute` : `${minutes} minutes`);
    if(seconds > 0) time.push(seconds <= 1 ? `${seconds} seconde` : `${seconds} secondes`);
    return time.join(", ");
};
const toRemaining = (date) => {
    var days = date.includes("d") ? date.split("d")[0] : "";
    var hours = date.includes("h") ? date.split("h")[0].slice(days ? days.length + 1 : 0) : "";
    var minutes = date.includes("m") ? date.split("m")[0].slice(days ? days.length + 1 : 0).slice(hours ? hours.length + 1 : 0) : "";
    var seconds = date.includes("s") ? date.split("s")[0].slice(days ? days.length + 1 : 0).slice(hours ? hours.length + 1 : 0).slice(minutes ? minutes.length + 1 : 0) : "";
    
    var duration = 0;
    if(days.length > 0) duration += parseInt(days) * 86400000;
    if(hours.length > 0) duration += parseInt(hours) * 3600000;
    if(minutes.length > 0) duration += parseInt(minutes) * 60000;
    if(seconds.length > 0) duration += parseInt(seconds) * 1000;

    return duration;
};
const toFormatDate = (date, format) => {
    if(typeof date !== "string" || typeof format !== "string") return false;
    
    var days = date.includes("d") ? date.split("d")[1] : "";
    var hours = date.includes("h") ? date.split("h")[1].slice(days ? days.length + 1 : 0) : "";
    var minutes = date.includes("m") ? date.split("m")[1].slice(days ? days.length + 1 : 0).slice(hours ? hours.length + 1 : 0) : "";
    var seconds = date.includes("s") ? date.split("s")[1].slice(days ? days.length + 1 : 0).slice(hours ? hours.length + 1 : 0).slice(minutes ? minutes.length + 1 : 0) : "";
    
    if(!days && !hours && !minutes && !seconds) return false;
    format.replace(/DD/g, days)
        .replace(/HH/g, hours < 10 ? `0${hours}` : hours)
        .replace(/mm/g, minutes < 10 ? `0${minutes}` : minutes)
        .replace(/ss/g, seconds < 10 ? `0${seconds}` : seconds)
    return {
        format: format,
        days: days,
        hours: hours,
        minutes: minutes,
        seconds: seconds
    };
};

module.exports = {
    codeGenerator, colors,
    toLocaleDate, toRemaining,
    toFormatDate
}
